searchData={"content_type":"text/markdown","items":[{"doc":"Set of tools to work with Distributed Identifiers (DIDs) in Bluesky / AT Protocol.","ref":"DIDTools.html","title":"DIDTools","type":"module"},{"doc":"```elixir\ndef deps do\n  [\n    {:did_tools, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"DIDTools.html#module-installation","title":"Installation - DIDTools","type":"module"},{"doc":"See `DIDTools.Resolver` module for more details usage.\n\n```elixir\niex> DIDTools.Resolver.did_by_handle(\"arathunku.com\")\n{:ok,\n %DIDTools.DID{\n   did: \"did:plc:yww4iq4ogs7f4bmqbiwfzbck\",\n   type: :plc,\n   resolver: :dns\n }}\n\n\niex> DIDTools.Resolver.doc_by_did(\"did:plc:ragtjsm2j2vknwkz3zp4oxrd\")\n{:ok,\n %DIDTools.Document{\n   did: %DIDTools.DID{\n     did: \"did:plc:ragtjsm2j2vknwkz3zp4oxrd\",\n     type: :plc,\n     resolver: nil\n   },\n   doc: %{\n     \"@context\" => [\"https://www.w3.org/ns/did/v1\",\n      \"https://w3id.org/security/multikey/v1\",\n      \"https://w3id.org/security/suites/secp256k1-2019/v1\"],\n     \"alsoKnownAs\" => [\"at://pfrazee.com\"],\n     \"id\" => \"did:plc:ragtjsm2j2vknwkz3zp4oxrd\",\n     \"service\" => [\n       %{\n         \"id\" => \"#atproto_pds\",\n         \"serviceEndpoint\" => \"https://morel.us-east.host.bsky.network\",\n         \"type\" => \"AtprotoPersonalDataServer\"\n       }\n     ],\n     \"verificationMethod\" => [\n       %{\n         \"controller\" => \"did:plc:ragtjsm2j2vknwkz3zp4oxrd\",\n         \"id\" => \"did:plc:ragtjsm2j2vknwkz3zp4oxrd#atproto\",\n         \"publicKeyMultibase\" => \"zQ3shbTzUCq5zuk7oSj5zaJndqWhjwGDaGuvBXpjg8C19qssW\",\n         \"type\" => \"Multikey\"\n       }\n     ]\n   }\n }}\n```","ref":"DIDTools.html#module-usage","title":"Usage - DIDTools","type":"module"},{"doc":"","ref":"DIDTools.DID.html","title":"DIDTools.DID","type":"module"},{"doc":"","ref":"DIDTools.DID.html#domain/1","title":"DIDTools.DID.domain/1","type":"function"},{"doc":"","ref":"DIDTools.DID.html#new/1","title":"DIDTools.DID.new/1","type":"function"},{"doc":"Creates a DID data struct from a DID string and a resolver.","ref":"DIDTools.DID.html#new/2","title":"DIDTools.DID.new/2","type":"function"},{"doc":"","ref":"DIDTools.DID.html#t:resolver/0","title":"DIDTools.DID.resolver/0","type":"type"},{"doc":"","ref":"DIDTools.DID.html#t:t/0","title":"DIDTools.DID.t/0","type":"type"},{"doc":"","ref":"DIDTools.Document.html","title":"DIDTools.Document","type":"module"},{"doc":"Returns a list of handles from a doc. They may not be all validated.\n\nCall `get_validated_handle/1` to get the first validated handle.","ref":"DIDTools.Document.html#get_handles/1","title":"DIDTools.Document.get_handles/1","type":"function"},{"doc":"Returns first validated handle","ref":"DIDTools.Document.html#get_validated_handle/1","title":"DIDTools.Document.get_validated_handle/1","type":"function"},{"doc":"Finds serviceEndpoint for labeler service and returns it if it's present.","ref":"DIDTools.Document.html#labeler_endpoint/1","title":"DIDTools.Document.labeler_endpoint/1","type":"function"},{"doc":"Finds serviceEndpoint for PDS service and returns it if it's present.","ref":"DIDTools.Document.html#pds_endpoint/1","title":"DIDTools.Document.pds_endpoint/1","type":"function"},{"doc":"","ref":"DIDTools.Document.html#t:t/0","title":"DIDTools.Document.t/0","type":"type"},{"doc":"Resolver for ATProto handles or DID. Following https://atproto.com/specs/handle spec.","ref":"DIDTools.Resolver.html","title":"DIDTools.Resolver","type":"module"},{"doc":"iex> alias DIDTools.{Resolver, DID, Document}\n    iex> {:ok, did} = Resolver.did_by_handle(\"arathunku.com\")\n    {:ok, %DID{did: \"did:plc:yww4iq4ogs7f4bmqbiwfzbck\", type: :plc, resolver: :dns}}\n    iex> {:ok, _doc} = DIDTools.Resolver.doc_by_did(did);\n    {:ok, %Document{\n       did: did,\n       doc: %{\n         \"@context\" => [\"https://www.w3.org/ns/did/v1\",\n          \"https://w3id.org/security/multikey/v1\",\n          \"https://w3id.org/security/suites/secp256k1-2019/v1\"],\n         \"alsoKnownAs\" => [\"at://arathunku.com\"],\n         \"id\" => \"did:plc:yww4iq4ogs7f4bmqbiwfzbck\",\n         \"service\" => [\n           %{\n             \"id\" => \"#atproto_pds\",\n             \"serviceEndpoint\" => \"https://enoki.us-east.host.bsky.network\",\n             \"type\" => \"AtprotoPersonalDataServer\"\n           }\n         ],\n         \"verificationMethod\" => [\n           %{\n             \"controller\" => \"did:plc:yww4iq4ogs7f4bmqbiwfzbck\",\n             \"id\" => \"did:plc:yww4iq4ogs7f4bmqbiwfzbck#atproto\",\n             \"publicKeyMultibase\" => \"zQ3shQ81CThGCgKCogk2Ci3DpHwNJZRjQK1ii2LfWtEDPw37G\",\n             \"type\" => \"Multikey\"\n           }\n         ]\n       }\n     }}\n\n    iex> alias DIDTools.{Resolver, DID, Document}\n    iex> Resolver.doc_by_did(\"did:web:feed.atproto.blue\")\n    {:ok, %Document{\n       did: %DID{\n         did: \"did:web:feed.atproto.blue\",\n         type: :web,\n         resolver: nil\n       },\n       doc: %{\n         \"@context\" => [\"https://www.w3.org/ns/did/v1\"],\n         \"id\" => \"did:web:feed.atproto.blue\",\n         \"service\" => [\n           %{\n             \"id\" => \"#bsky_fg\",\n             \"serviceEndpoint\" => \"https://feed.atproto.blue\",\n             \"type\" => \"BskyFeedGenerator\"\n           }\n         ]\n       }\n     }}","ref":"DIDTools.Resolver.html#module-usage","title":"Usage - DIDTools.Resolver","type":"module"},{"doc":"Get DID by handle. It will first try to resolve by DNS, then by HTTP.\n\nDNS resolve expects to find a TXT record with the key `_atproto` and a value starting with `did=`.\nRight now defaults to Cloudflare DNS nameservers, but alternative nameserver can be configured.\n(`config :did_tools, dns_options: [nameservers: [{{8, 8, 8, 8}, 53}, {{8, 8, 4, 4}, 53}]`).\n\nHTTP resolve expects to receive a plain text content with a DID string\nat `https:// /.well-known/atproto-did`.\n\nTimeouts and max redirects are very limited (within ~5s and 5 redirects).","ref":"DIDTools.Resolver.html#did_by_handle/1","title":"DIDTools.Resolver.did_by_handle/1","type":"function"},{"doc":"Fetches a DID document by DID string or DID struct.\n\nSee `DIDTools.Document` for the document structure and available methods.","ref":"DIDTools.Resolver.html#doc_by_did/1","title":"DIDTools.Resolver.doc_by_did/1","type":"function"},{"doc":"# DIDTools\n\n[![Actions Status](https://github.com/arathunku/did_tools/actions/workflows/elixir-build-and-test.yml/badge.svg)](https://github.com/arathunku/did_tools/actions/workflows/elixir-build-and-test.yml) \n[![Hex.pm](https://img.shields.io/hexpm/v/did_tools.svg?style=flat)](https://hex.pm/packages/did_tools)\n[![Documentation](https://img.shields.io/badge/hex-docs-lightgreen.svg?style=flat)](https://hexdocs.pm/did_tools)\n[![License](https://img.shields.io/hexpm/l/did_tools.svg?style=flat)](https://github.com/arathunku/did_tools/blob/main/LICENSE.md)\n\n<!-- @moduledoc -->\n\nSet of tools to work with Distributed Identifiers (DIDs) in Bluesky / AT Protocol.","ref":"readme.html","title":"Overview","type":"extras"},{"doc":"```elixir\ndef deps do\n  [\n    {:did_tools, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - Overview","type":"extras"},{"doc":"See `DIDTools.Resolver` module for more details usage.\n\n```elixir\niex> DIDTools.Resolver.did_by_handle(\"arathunku.com\")\n{:ok,\n %DIDTools.DID{\n   did: \"did:plc:yww4iq4ogs7f4bmqbiwfzbck\",\n   type: :plc,\n   resolver: :dns\n }}\n\n\niex> DIDTools.Resolver.doc_by_did(\"did:plc:ragtjsm2j2vknwkz3zp4oxrd\")\n{:ok,\n %DIDTools.Document{\n   did: %DIDTools.DID{\n     did: \"did:plc:ragtjsm2j2vknwkz3zp4oxrd\",\n     type: :plc,\n     resolver: nil\n   },\n   doc: %{\n     \"@context\" => [\"https://www.w3.org/ns/did/v1\",\n      \"https://w3id.org/security/multikey/v1\",\n      \"https://w3id.org/security/suites/secp256k1-2019/v1\"],\n     \"alsoKnownAs\" => [\"at://pfrazee.com\"],\n     \"id\" => \"did:plc:ragtjsm2j2vknwkz3zp4oxrd\",\n     \"service\" => [\n       %{\n         \"id\" => \"#atproto_pds\",\n         \"serviceEndpoint\" => \"https://morel.us-east.host.bsky.network\",\n         \"type\" => \"AtprotoPersonalDataServer\"\n       }\n     ],\n     \"verificationMethod\" => [\n       %{\n         \"controller\" => \"did:plc:ragtjsm2j2vknwkz3zp4oxrd\",\n         \"id\" => \"did:plc:ragtjsm2j2vknwkz3zp4oxrd#atproto\",\n         \"publicKeyMultibase\" => \"zQ3shbTzUCq5zuk7oSj5zaJndqWhjwGDaGuvBXpjg8C19qssW\",\n         \"type\" => \"Multikey\"\n       }\n     ]\n   }\n }}\n```","ref":"readme.html#usage","title":"Usage - Overview","type":"extras"},{"doc":"# Changelog\n\n<!--","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"<!--","ref":"changelog.html#bug-fixes","title":"Bug fixes --> - Changelog","type":"extras"},{"doc":"<!--","ref":"changelog.html#enhancements","title":"Enhancements --> - Changelog","type":"extras"},{"doc":"","ref":"changelog.html#backwards-incompatible-changes","title":"Backwards incompatible changes --> - Changelog","type":"extras"},{"doc":"Init release","ref":"changelog.html#0-1-0-2024-03-29","title":"0.1.0 (2024-03-29) - Changelog","type":"extras"},{"doc":"# MIT License\n\nCopyright (c) 2024 Michal Forys\n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE\nLIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION\nOF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION\nWITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html","title":"License","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}